@@ -2,18 +2,18 @@ library(discSurv)
 
 ###########################################
 # Test
-# devResidShort (dataSet, hazards)
-# adjDevResidShort (dataSet, hazards)
+# devResid (dataShort, hazards)
+# adjDevResid (dataShort, hazards)
 
 # Preprocessing
 library(survival)
 set.seed(0)
 Indizes <- sample(1:dim(transplant)[1], 100)
 transplant2 <- transplant[Indizes, ]
-censColumns <- data.frame(model.matrix(~event, transplant2)[,-1])
-transplant2 <- data.frame(transplant2, death=censColumns[,1])
+eventColumns <- data.frame(model.matrix(~event, transplant2)[,-1])
+transplant2 <- data.frame(transplant2, death=eventColumns[,1])
 transplant2$futime <- transplant2$futime+1
-transplantLong <- dataLong(dataSet=transplant2, timeColumn="futime", censColumn="death")
+transplantLong <- dataLong(dataShort=transplant2, timeColumn="futime", eventColumn="death")
 transplantLong$timeInt <- as.numeric(as.character(transplantLong$timeInt))
 
 # Estimate discrete hazards with gam
@@ -22,7 +22,7 @@ fitGAM <- gam(y ~ s(timeInt) + sex + abo + year, data=transplantLong, family=bin
 hazPreds <- predict(fitGAM, type="response")
 
 # Calculate deviance residuals
-results <- devResidShort(dataSet=transplantLong, hazards=hazPreds)
+results <- devResid(dataLong=transplantLong, hazards=hazPreds)
 results
-results <- adjDevResidShort(dataSet=transplantLong, hazards=hazPreds)
+results <- adjDevResid(dataLong=transplantLong, hazards=hazPreds)
 results
